### Added:

* `--link-conflict` flag to specify what to do when a link already exists in the
  ~/.local/bin directory. The default is `error`, which will cause the install to
  fail. The other options are `skip` and `overwrite`.
